=======
Credits
=======

Maintainer
----------

* Machado, F. A. M.; Castaldoni, R. C.  <f.a.moraes.machado@gmail.com>

Contributors
------------

None yet. Why not be the first? See: CONTRIBUTING.rst
